PreprocessingOptions class
HTML preprocessing options for document cleanup before conversion.
Constructors
- PreprocessingOptions({required bool enabled, required PreprocessingPreset preset, required bool removeForms})
-
const
Properties
- enabled → bool
-
Enable HTML preprocessing globally
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- preset → PreprocessingPreset
-
Preprocessing preset level (Minimal, Standard, Aggressive)
final
- removeForms → bool
-
Remove form elements (forms, inputs, buttons, etc.)
final
-
Remove navigation elements (nav, breadcrumbs, menus, sidebars)
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override