StructuredDataType enum
Structured data format type.
Identifies the schema/format used for structured data markup.
Values
- jsonLd → const StructuredDataType
-
JSON-LD (JSON for Linking Data) script blocks
- microdata → const StructuredDataType
-
HTML5 Microdata attributes (itemscope, itemtype, itemprop)
- rdFa → const StructuredDataType
-
RDF in Attributes (RDFa) markup
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
StructuredDataType> - A constant List of the values in this enum, in order of their declaration.